@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 from zvt.contract import IntervalLevel
-from zvt.factors.ma.ma_factor import CrossMaFactor
 from zvt.factors.target_selector import TargetSelector
-from zvt.factors.technical_factor import BullFactor
-
+from zvt.factors.ma.ma_factor import CrossMaFactor
+from zvt.factors import BullFactor
 from zvt.trader.trader import StockTrader
 
 
 class MyMaTrader(StockTrader):
-    def init_selectors(self, entity_ids, entity_schema, exchanges, codes, start_timestamp, end_timestamp):
+    def init_selectors(self, entity_ids, entity_schema, exchanges, codes, start_timestamp, end_timestamp,
+                       adjust_type=None):
         myselector = TargetSelector(entity_ids=entity_ids, entity_schema=entity_schema, exchanges=exchanges,
                                     codes=codes, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
                                     provider='joinquant')
@@ -16,20 +16,22 @@ class MyMaTrader(StockTrader):
         myselector.add_filter_factor(
             CrossMaFactor(entity_ids=entity_ids, entity_schema=entity_schema, exchanges=exchanges,
                           codes=codes, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
-                          windows=[5, 10], need_persist=False))
+                          windows=[5, 10], need_persist=False, adjust_type=adjust_type))
 
         self.selectors.append(myselector)
 
 
 class MyBullTrader(StockTrader):
-    def init_selectors(self, entity_ids, entity_schema, exchanges, codes, start_timestamp, end_timestamp):
+    def init_selectors(self, entity_ids, entity_schema, exchanges, codes, start_timestamp, end_timestamp,
+                       adjust_type=None):
         myselector = TargetSelector(entity_ids=entity_ids, entity_schema=entity_schema, exchanges=exchanges,
                                     codes=codes, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
                                     provider='joinquant')
 
         myselector.add_filter_factor(
             BullFactor(entity_ids=entity_ids, entity_schema=entity_schema, exchanges=exchanges,
-                       codes=codes, start_timestamp=start_timestamp, end_timestamp=end_timestamp))
+                       codes=codes, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
+                       adjust_type=adjust_type))
 
         self.selectors.append(myselector)
 
