@@ -3,6 +3,7 @@ import logging
 import numbers
 from decimal import *
 from enum import Enum
+from urllib import parse
 
 import pandas as pd
 
@@ -70,7 +71,7 @@ def pct_to_float(the_str, default=None):
 
 
 def json_callback_param(the_str):
-    json_str = the_str[the_str.index("(") + 1:the_str.index(")")].replace('null', 'None')
+    json_str = the_str[the_str.index("(") + 1:the_str.rindex(")")].replace('null', 'None')
     return eval(json_str)
 
 
@@ -197,7 +198,17 @@ def iterate_with_step(data, sub_size=100):
             yield data[sub_size * step:sub_size * (step + 1)]
 
 
+def url_unquote(url):
+    return parse.unquote(url)
+
+
+def parse_url_params(url):
+    url = url_unquote(url)
+    return parse.parse_qs(parse.urlsplit(url).query)
+
+
 # the __all__ is generated
 __all__ = ['first_item_to_float', 'second_item_to_float', 'add_func_to_value', 'to_float', 'pct_to_float',
            'json_callback_param', 'fill_domain_from_dict', 'read_csv', 'marshal_object_for_ui',
-           'chrome_copy_header_to_dict', 'to_positive_number', 'multiple_number', 'add_to_map_list']
+           'chrome_copy_header_to_dict', 'to_positive_number', 'multiple_number', 'add_to_map_list',
+           'iterate_with_step', 'url_unquote', 'parse_url_params']
